@@ -13,6 +13,7 @@
 # under the License.
 
 import requests_mock
+import re
 from testtools import TestCase
 
 from grafana_dashboards.grafana import Grafana
@@ -39,6 +40,8 @@ DASHBOARD_NOT_FOUND = {
     "message": "Dashboard not found"
 }
 
+UID_URL_MATCHER = re.compile(r'api/dashboards/uid/[a-fA-F\d]{10}')
+
 
 class TestCaseGrafana(TestCase):
 
@@ -61,14 +64,12 @@ class TestCaseGrafana(TestCase):
     @requests_mock.Mocker()
     def test_create_dashboard_new(self, mock_requests):
         def post_callback(request, context):
-            mock_requests.get(
-                '/api/dashboards/db/new-dashboard', json=CREATE_NEW_DASHBOARD)
+            mock_requests.get(UID_URL_MATCHER, json=CREATE_NEW_DASHBOARD)
             return True
 
         mock_requests.post('/api/dashboards/db/', json=post_callback)
         mock_requests.get(
-            '/api/dashboards/db/new-dashboard', json=DASHBOARD_NOT_FOUND,
-            status_code=404)
+            UID_URL_MATCHER, json=DASHBOARD_NOT_FOUND, status_code=404)
 
         data = {
             "dashboard": {
@@ -83,8 +84,7 @@ class TestCaseGrafana(TestCase):
     @requests_mock.Mocker()
     def test_create_dashboard_overwrite(self, mock_requests):
         mock_requests.post('/api/dashboards/db/')
-        mock_requests.get(
-            '/api/dashboards/db/new-dashboard', json=CREATE_NEW_DASHBOARD)
+        mock_requests.get(UID_URL_MATCHER, json=CREATE_NEW_DASHBOARD)
         data = {
             "dashboard": {
                 "title": "New dashboard",
@@ -98,8 +98,7 @@ class TestCaseGrafana(TestCase):
     @requests_mock.Mocker()
     def test_create_dashboard_existing(self, mock_requests):
         mock_requests.post('/api/dashboards/db/')
-        mock_requests.get(
-            '/api/dashboards/db/new-dashboard', json=CREATE_NEW_DASHBOARD)
+        mock_requests.get(UID_URL_MATCHER, json=CREATE_NEW_DASHBOARD)
         data = {
             "dashboard": {
                 "title": "New dashboard",
@@ -114,10 +113,9 @@ class TestCaseGrafana(TestCase):
 
     @requests_mock.Mocker()
     def test_delete_dashboard(self, mock_requests):
-        mock_requests.delete('/api/dashboards/db/new-dashboard')
+        mock_requests.delete(UID_URL_MATCHER)
         mock_requests.get(
-            '/api/dashboards/db/new-dashboard', json=DASHBOARD_NOT_FOUND,
-            status_code=404)
+            UID_URL_MATCHER, json=DASHBOARD_NOT_FOUND, status_code=404)
         self.grafana.dashboard.delete('new-dashboard')
 
     @requests_mock.Mocker()
